<?php

/**
 * This is the model class for table "action".
 *
 * The followings are the available columns in table 'action':
 * @property integer $id
 * @property integer $action_category_id
 * @property integer $rank
 * @property string $link
 * @property string $contacts_data
 * @property integer $is_finished
 * @property integer $hidden
 * @property string $code
 * @property string $date_start
 * @property string $date_end
 *
 * The followings are the available model relations:
 * @property ActionCategory $actionCategory
 * @property ActionI18n[] $i18ns
 * @property ActionI18n $i18n
 */
class Action extends CActiveRecord
{
    /**
     * Returns the static model of the specified AR class.
     * @param string $className active record class name.
     * @return Action the static model class
     */
    public static function model($className = __CLASS__)
    {
        return parent::model($className);
    }


    public function behaviors()
    {
        return array(
            'imageBehavior' => array(
                'class' => 'ImageARBehavior',
                'attribute' => 'image', // this must exist
                'extension' => 'png, gif, jpg, jpeg', // possible extensions, comma separated
                'prefix' => 'img_',
                'relativeWebRootFolder' => 'images/action', // this folder must exist

//                'forceExt' => 'png',
                'formats' => array(
                    'preview' => array(
                        'suffix' => '_preview',
                        'process' => array(
                            'resize' => array(796, null),
//                            'crop' => array(133, 57, 'center'),
                        ),
                    ),
                    'normal' => array(),
                ),

                'defaultName' => 'default',
            ),
        );
    }

    /**
     * @return string the associated database table name
     */
    public function tableName()
    {
        return 'action';
    }


    public $image;
    /**
     * @return array validation rules for model attributes.
     */
    public function rules()
    {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('action_category_id', 'required'),
            array('action_category_id, rank, is_finished', 'numerical', 'integerOnly' => true),
            array('link', 'length', 'max' => 64),
            array('link', 'unique',),
            array('contactIds', 'safe'),
            array('image, date_start, date_end', 'safe'),
            // The following rule is used by search().
            // Please remove those attributes that should not be searched.
            array('id, action_category_id, rank, link, contacts_data, is_finished', 'safe', 'on' => 'search'),
            array('hidden, code', 'safe'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations()
    {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'actionCategory' => array(self::BELONGS_TO, 'ActionCategory', 'action_category_id'),
            'i18ns' => array(self::HAS_MANY, 'ActionI18n', 'id', 'index' => 'lang'),
            'i18n' => array(self::HAS_ONE, 'ActionI18n', 'id', 'condition' => 'lang=\'' . Yii::app()->language . '\''),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels()
    {
        return array(
            'id' => 'ID',
            'action_category_id' => 'Категория акции',
            'is_finished' => 'Акция завершена',
            'rank' => 'Rank',
            'link' => 'Псевдоним в адресной строке',
            'contactIds' => 'Контакты для отображения в сайдбаре',
            'hidden' => 'Страница скрыта',
            'image' => 'Фото',
            'date_start' => 'Начало акции',
            'date_end' => 'Конец акции'
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
     */
    public function search()
    {
        // Warning: Please modify the following code to remove attributes that
        // should not be searched.

        $criteria = new CDbCriteria;

////        $criteria->compare('id', $this->id);
        $criteria->compare('action_category_id', $this->action_category_id);
        $criteria->compare('rank', $this->rank);
        $criteria->compare('link', $this->link, true);
        $criteria->compare('contacts_data', $this->contacts_data, true);
        $criteria->compare('is_finished', $this->is_finished);

        $sort = new CSort();
        $sort->defaultOrder = array(
            'rank' => false,
        );

        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
            'sort' => $sort,
        ));
    }

    public function save($runValidation = true, $attributes = null)
    {
        $r = parent::save($runValidation, $attributes);
        if (empty($this->link)) {
            $this->link = $this->id;
            $this->saveAttributes($this->attributes);
        }
        return $r;
    }

    public function getContactIds()
    {
        return explode(',', $this->contacts_data);
    }

    public function setContactIds($value)
    {
        if (is_array($value))
            $this->contacts_data = implode(',', $value);
        else
            $this->contacts_data = $value;
    }



    public function getDayLeft(){
        if(!empty($this->date_end)) {
            $datetime1 = new DateTime("now");
            $datetime2 = new DateTime($this->date_end);
            $interval = $datetime1->diff($datetime2);
            return $interval->format('%d');
        } else {
            return "";
        }

    }


    public function getStatus(){
        if($this->is_finished || !empty($this->date_end) && strtotime($this->date_end) < strtotime(date('Y-m-d'))){
            return 'end';
        } else {
            return 'active';
        }
    }
}