<?php

/**
 * This is the model class for table "albums_section".
 *
 * The followings are the available columns in table 'albums_section':
 * @property integer $id
 * @property integer $header_gallery_id
 *
 * The followings are the available model relations:
 * @property Album[] $albums
 * @property AlbumsSectionI18n[] $i18ns
 * @property AlbumsSectionI18n $i18n
 */
class AlbumsSection extends CActiveRecord
{
	/**
	 * Returns the static model of the specified AR class.
	 * @param string $className active record class name.
	 * @return AlbumsSection the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
	
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'albums_section';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('header_gallery_id', 'numerical', 'integerOnly'=>true),
			// The following rule is used by search().
			// Please remove those attributes that should not be searched.
			array('id, header_gallery_id', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'albums' => array(self::HAS_MANY, 'Album', 'albums_section_id'),
			'i18ns' => array(self::HAS_MANY, 'AlbumsSectionI18n', 'id', 'index' => 'lang'),
			'i18n' => array(self::HAS_ONE, 'AlbumsSectionI18n', 'id', 'condition' => 'lang=\'' . Yii::app()->language . '\''),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
            'header_gallery_id' => 'Галереея в шапке',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
	 */
	public function search()
	{
		// Warning: Please modify the following code to remove attributes that
		// should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('header_gallery_id',$this->header_gallery_id);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}
    public function behaviors()
    {
        return array(
            'galleryBehavior' => array(
                'class' => 'GalleryBehavior',
                'idAttribute' => 'header_gallery_id',
                'versions' => array(
                    'gallery' => array(
                        'centeredpreview' => array(1008, 115),
                    )
                ),
                'name' => true,
                'description' => true,
            ),
        );
    }
}