<?php

/**
 * This is the model class for table "brand".
 *
 * The followings are the available columns in table 'brand':
 * @property integer $id
 *
 * The followings are the available model relations:
 * @property BrandI18n[] $i18ns
 * @property BrandI18n $i18n
 * @property Partner[] $partners
 *
 * @property ImageARBehavior $imageBehavior
 */
class Brand extends CActiveRecord implements INodeCrudModel
{
    /**
     * Returns the static model of the specified AR class.
     * @param string $className active record class name.
     * @return Brand the static model class
     */
    public static function model($className = __CLASS__)
    {
        return parent::model($className);
    }

    /**
     * @return string the associated database table name
     */
    public function tableName()
    {
        return 'brand';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules()
    {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            // The following rule is used by search().
            // Please remove those attributes that should not be searched.
            array('id', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations()
    {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'i18ns' => array(self::HAS_MANY, 'BrandI18n', 'id', 'index' => 'lang'),
            'i18n' => array(self::HAS_ONE, 'BrandI18n', 'id', 'condition' => 'lang=\'' . Yii::app()->language . '\''),
            'partners' => array(self::MANY_MANY, 'Partner', 'partner_has_brand(brand_id, partner_id)'),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels()
    {
        return array(
            'id' => 'ID',
            'image' => 'Лого марки авто (190x140)',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
     */
    public function search()
    {
        // Warning: Please modify the following code to remove attributes that
        // should not be searched.

        $criteria = new CDbCriteria;

////        $criteria->compare('id', $this->id);

        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
        ));
    }


    public $image;

    public function behaviors()
    {
        return array(
            'imageBehavior' => array(
                'class' => 'ImageARBehavior',
                'attribute' => 'image', // this must exist
                'extension' => 'png, gif, jpg, jpeg', // possible extensions, comma separated
                'prefix' => 'img_',
                'relativeWebRootFolder' => 'images/aboutBrands', // this folder must exist

                'forceExt' => 'png',
                'formats' => array(
                    'small' => array(
                        'suffix' => '_small',
                        'process' => array(
                            'resize' => array('80%', '80%'),
//                            'crop' => array(133, 57, 'center'),
                        ),
                    ),
                    'normal' => array(),
                ),

                'defaultName' => 'default',
            ),
        );
    }

    /**
     * @param Node $node
     * @return void
     */
    public function setNode($node)
    {
        //no filtering by section
    }
}