<?php

/**
 * This is the model class for table "contact".
 *
 * The followings are the available columns in table 'contact':
 * @property integer $id
 * @property string $email
 * @property string $bcc_email
 * @property string $phone
 *
 * The followings are the available model relations:
 * @property ContactI18n[] $i18ns
 * @property ContactI18n $i18n
 *
 * @property ImageARBehavior $imageBehavior
 */
class Contact extends CActiveRecord
{
    /**
     * Returns the static model of the specified AR class.
     * @param string $className active record class name.
     * @return Contact the static model class
     */
    public static function model($className = __CLASS__)
    {
        return parent::model($className);
    }

    /**
     * @return string the associated database table name
     */
    public function tableName()
    {
        return 'contact';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules()
    {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('email, phone', 'length', 'max' => 45),
            array('bcc_email', 'length', 'max' => 512),
            // The following rule is used by search().
            // Please remove those attributes that should not be searched.
            array('image', 'safe'),
            array('id, email, phone', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations()
    {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'i18ns' => array(self::HAS_MANY, 'ContactI18n', 'id', 'index' => 'lang'),
            'i18n' => array(self::HAS_ONE, 'ContactI18n', 'id', 'condition' => 'lang=\'' . Yii::app()->language . '\''),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels()
    {
        return array(
            'id' => 'ID',
            'email' => 'E-Mail',
            'bcc_email' => 'E-Mail для скрытых копий писем',
            'phone' => 'Номер телефона',
            'image' => 'Фото',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
     */
    public function search()
    {
        // Warning: Please modify the following code to remove attributes that
        // should not be searched.

        $criteria = new CDbCriteria;

////        $criteria->compare('id', $this->id);
        $criteria->compare('email', $this->email, true);
        $criteria->compare('phone', $this->phone, true);

        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
        ));
    }


    public $image;

    public function behaviors()
    {
        return array(
            'imageBehavior' => array(
                'class' => 'ImageARBehavior',
                'attribute' => 'image', // this must exist
                'extension' => 'png, gif, jpg, jpeg', // possible extensions, comma separated
                'prefix' => 'img_',
                'relativeWebRootFolder' => 'images/contacts', // this folder must exist

//                'forceExt' => 'png',
                'formats' => array(
                    'preview' => array(
                        'suffix' => '_preview',
                        'process' => array(
                            'resize' => array(140, null),
//                            'crop' => array(133, 57, 'center'),
                        ),
                    ),
                    'normal' => array(),
                ),

                'defaultName' => 'default',
            ),
        );
    }

    /**
     * @static
     * @param $selected
     * @return array
     */
    public static function listWithSelected($selected)
    {
        $items = CHtml::listData(Contact::model()->findAll(), 'id', 'i18n.name');
        if(empty($selected)) return $items;
        $res = array();
        foreach($selected as $i)
        if(!empty($items[$i])){
            $res[$i] = $items[$i];
            unset($items[$i]);
        } else{
            unset($items[$i]);
        }
        $res += $items;
        return $res;
    }
}