<?php

/**
 * This is the model class for table "job".
 *
 * The followings are the available columns in table 'job':
 * @property integer $id
 * @property string $contacts_data
 * @property string $link
 * @property integer $jobs_section_id
 * @property integer $hidden
 * @property string $code
 *
 * The followings are the available model relations:
 * @property JobI18n[] $i18ns
 * @property JobI18n $i18n
 */
class Job extends CActiveRecord implements INodeCrudModel
{
    /**
     * Returns the static model of the specified AR class.
     * @param string $className active record class name.
     * @return Job the static model class
     */
    public static function model($className = __CLASS__)
    {
        return parent::model($className);
    }

    /**
     * @return string the associated database table name
     */
    public function tableName()
    {
        return 'job';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules()
    {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('link', 'length', 'max' => 64),
            array('link', 'unique',),
            array('contactIds', 'safe'),
            // The following rule is used by search().
            // Please remove those attributes that should not be searched.
            array('id, contacts_data, link', 'safe', 'on' => 'search'),
            array('hidden, code', 'safe'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations()
    {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'i18ns' => array(self::HAS_MANY, 'JobI18n', 'id', 'index' => 'lang'),
            'i18n' => array(self::HAS_ONE, 'JobI18n', 'id', 'condition' => 'lang=\'' . Yii::app()->language . '\''),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels()
    {
        return array(
            'id' => 'ID',
            'link' => 'Псевдоним в адресной строке',
            'contactIds' => 'Контакты для отображения в сайдбаре',
            'hidden' => 'Страница скрыта',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
     */
    public function search()
    {
        // Warning: Please modify the following code to remove attributes that
        // should not be searched.

        $criteria = new CDbCriteria;

////        $criteria->compare('id', $this->id);
        $criteria->compare('jobs_section_id', $this->jobs_section_id);
        $criteria->compare('contacts_data', $this->contacts_data, true);
        $criteria->compare('link', $this->link, true);

        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
        ));
    }

    public function getContactIds()
    {
        return explode(',', $this->contacts_data);
    }

    public function setContactIds($value)
    {
        if (is_array($value))
            $this->contacts_data = implode(',', $value);
        else
            $this->contacts_data = $value;
    }

    public function save($runValidation = true, $attributes = null)
    {
        $r = parent::save($runValidation, $attributes);
        if (empty($this->link)) {
            $this->link = $this->id;
            $this->saveAttributes($this->attributes);
        }
        return $r;
    }

    /**
     * @param Node $node
     * @return void
     */
    public function setNode($node)
    {
        $this->jobs_section_id = $node->data_id;
    }
}