<?php

/**
 * This is the model class for table "jobs_section_i18n".
 *
 * The followings are the available columns in table 'jobs_section_i18n':
 * @property integer $id
 * @property string $lang
 * @property string $page_name
 * @property string $content1
 * @property string $content2
 * @property string $title
 * @property string $keywords
 * @property string $description
 *
 * The followings are the available model relations:
 * @property JobsSection $jobsSection
 */
class JobsSectionI18n extends CActiveRecord
{
    /**
     * Returns the static model of the specified AR class.
     * @param string $className active record class name.
     * @return JobsSectionI18n the static model class
     */
    public static function model($className = __CLASS__)
    {
        return parent::model($className);
    }

    /**
     * @return string the associated database table name
     */
    public function tableName()
    {
        return 'jobs_section_i18n';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules()
    {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('page_name', 'length', 'max' => 45),
            array('title', 'length', 'max' => 512),
            array('content1, content2, keywords, description', 'safe'),
            // The following rule is used by search().
            // Please remove those attributes that should not be searched.
            array('id, lang, page_name, content1, content2, title, keywords, description', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations()
    {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'jobsSection' => array(self::BELONGS_TO, 'JobsSection', 'id'),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels()
    {
        return array(
            'id' => 'ID',
            'lang' => 'Язык',
            'page_name' => 'Название страницы',
            'content1' => 'Содержимое страницы до списка',
            'content2' => 'Содержимое страницы после списка',
            'title' => 'Заголовок',
            'keywords' => 'Ключевые слова',
            'description' => 'Описание',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
     */
    public function search()
    {
        // Warning: Please modify the following code to remove attributes that
        // should not be searched.

        $criteria = new CDbCriteria;

////        $criteria->compare('id', $this->id);
        $criteria->compare('lang', $this->lang, true);
        $criteria->compare('page_name', $this->page_name, true);
        $criteria->compare('content1', $this->content1, true);
        $criteria->compare('content2', $this->content2, true);
        $criteria->compare('title', $this->title, true);
        $criteria->compare('keywords', $this->keywords, true);
        $criteria->compare('description', $this->description, true);

        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
        ));
    }
}