<?php

/**
 * This is the model class for table "question".
 *
 * The followings are the available columns in table 'question':
 * @property integer $id
 * @property integer $question_category_id
 *
 * The followings are the available model relations:
 * @property QuestionCategory $questionCategory
 * @property QuestionI18n[] $i18ns
 * @property QuestionI18n $i18n
 */
class Question extends CActiveRecord implements INodeCrudModel
{
    /**
     * Returns the static model of the specified AR class.
     * @param string $className active record class name.
     * @return Question the static model class
     */
    public $question_root_id;

    public static function model($className = __CLASS__)
    {
        return parent::model($className);
    }

    /**
     * @return string the associated database table name
     */
    public function tableName()
    {
        return 'question';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules()
    {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('question_category_id', 'required'),
            array('question_category_id', 'numerical', 'integerOnly' => true),
            // The following rule is used by search().
            // Please remove those attributes that should not be searched.
            array('id, question_category_id', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations()
    {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'questionCategory' => array(self::BELONGS_TO, 'QuestionCategory', 'question_category_id'),
            'i18ns' => array(self::HAS_MANY, 'QuestionI18n', 'id', 'index' => 'lang'),
            'i18n' => array(self::HAS_ONE, 'QuestionI18n', 'id', 'condition' => 'lang=\'' . Yii::app()->language . '\''),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels()
    {
        return array(
            'id' => 'ID',
            'question_category_id' => 'Категория вопроса',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
     */
    public function search()
    {
        // Warning: Please modify the following code to remove attributes that
        // should not be searched.

        $criteria = new CDbCriteria;

//        $criteria->compare('id', $this->id);
        if (isset($this->question_category_id))
            $criteria->compare('question_category_id', $this->question_category_id);
        else
            $criteria->addInCondition('question_category_id', array_keys($this->getQuestionCategories()));
        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
        ));
    }

    public function getQuestionCategories()
    {
        $criteria = new CDbCriteria();
        $criteria->compare('question_root_id', $this->question_root_id);

        return CHtml::listData(QuestionCategory::model()->findAll($criteria), 'id', 'i18n.name');
    }

    /**
     * @param Node $node
     * @return void
     */
    public function setNode($node)
    {
        $this->question_root_id = $node->data_id;
    }
}