<?php

/**
 * This is the model class for table "review_i18n".
 *
 * The followings are the available columns in table 'review_i18n':
 * @property integer $id
 * @property string $lang
 * @property string $name
 * @property string $comment
 * @property string $link_text
 * @property string $link_url
 *
 * The followings are the available model relations:
 * @property Review $review
 */
class ReviewI18n extends CActiveRecord
{
    /**
     * Returns the static model of the specified AR class.
     * @param string $className active record class name.
     * @return ReviewI18n the static model class
     */
    public static function model($className = __CLASS__)
    {
        return parent::model($className);
    }

    /**
     * @return string the associated database table name
     */
    public function tableName()
    {
        return 'review_i18n';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules()
    {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('name', 'length', 'max' => 64),
            array('link_text, link_url', 'length', 'max' => 128),
            array('comment', 'safe'),
            // The following rule is used by search().
            // Please remove those attributes that should not be searched.
            array('id, lang, name, comment, link_text, link_url', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations()
    {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'review' => array(self::BELONGS_TO, 'Review', 'id'),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels()
    {
        return array(
            'id' => 'ID',
            'lang' => 'Lang',
            'name' => 'Имя',
            'comment' => 'Отзыв',
            'link_text' => 'Текст ссылки',
            'link_url' => 'Ссылка',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
     */
    public function search()
    {
        // Warning: Please modify the following code to remove attributes that
        // should not be searched.

        $criteria = new CDbCriteria;

//        $criteria->compare('id', $this->id);
        $criteria->compare('lang', $this->lang, true);
        $criteria->compare('name', $this->name, true);
        $criteria->compare('comment', $this->comment, true);
        $criteria->compare('link_text', $this->link_text, true);
        $criteria->compare('link_url', $this->link_url, true);

        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
        ));
    }
}