<?php

/**
 * This is the model class for table "service".
 *
 * The followings are the available columns in table 'service':
 * @property integer $id
 * @property integer $service_category_id
 * @property integer $rank
 * @property string $link
 * @property string $contacts_data
 * @property integer $hidden
 * @property string $code
 *
 * The followings are the available model relations:
 * @property ServiceCategory $serviceCategory
 * @property ServiceI18n[] $i18ns
 * @property ServiceI18n $i18n
 */
class Service extends CActiveRecord
{
    /**
     * Returns the static model of the specified AR class.
     * @param string $className active record class name.
     * @return Service the static model class
     */
    public static function model($className = __CLASS__)
    {
        return parent::model($className);
    }

    /**
     * @return string the associated database table name
     */
    public function tableName()
    {
        return 'service';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules()
    {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('service_category_id', 'required'),
            array('service_category_id, rank', 'numerical', 'integerOnly' => true),
            array('contactIds', 'safe'),
            array('link', 'length', 'max' => 64),
            array('link', 'unique',),
            // The following rule is used by search().
            // Please remove those attributes that should not be searched.
            array('id, service_category_id, rank, contacts_data', 'safe', 'on' => 'search'),
            array('hidden, code', 'safe'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations()
    {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'serviceCategory' => array(self::BELONGS_TO, 'ServiceCategory', 'service_category_id'),
            'i18ns' => array(self::HAS_MANY, 'ServiceI18n', 'id', 'index' => 'lang'),
            'i18n' => array(self::HAS_ONE, 'ServiceI18n', 'id', 'condition' => 'lang=\'' . Yii::app()->language . '\''),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels()
    {
        return array(
            'id' => 'ID',
            'service_category_id' => 'Категория услуг',
            'rank' => 'Rank',
            'link' => 'Псевдоним в адресной строке',
            'contactIds' => 'Контакты для отображения в сайдбаре',
            'hidden' => 'Страница скрыта',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
     */
    public function search()
    {
        // Warning: Please modify the following code to remove attributes that
        // should not be searched.

        $criteria = new CDbCriteria;

//        $criteria->compare('id', $this->id);
        $criteria->compare('service_category_id', $this->service_category_id);
        $criteria->compare('rank', $this->rank);
        $criteria->compare('contacts_data', $this->contacts_data, true);

        $sort = new CSort();
        $sort->defaultOrder = array(
            'rank' => false,
        );

        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
            'sort' => $sort,
        ));
    }

    public function save($runValidation = true, $attributes = null)
    {
        $r = parent::save($runValidation, $attributes);
        if (empty($this->link)) {
            $this->link = $this->id;
            $this->saveAttributes($this->attributes);
        }
        return $r;
    }

    public function getContactIds()
    {
        return explode(',', $this->contacts_data);
    }

    public function setContactIds($value)
    {
        if (is_array($value))
            $this->contacts_data = implode(',', $value);
        else
            $this->contacts_data = $value;
    }
}