<?php

/**
 * This is the model class for table "show".
 *
 * The followings are the available columns in table 'show':
 * @property integer $id
 * @property integer $news_category_id
 * @property string $date
 * @property string $dateRu
 * @property string $video_url
 *
 * The followings are the available model relations:
 * @property NewsCategory $newsCategory
 * @property ShowI18n[] $i18ns
 * @property ShowI18n $i18n
 */
class Show extends CActiveRecord implements INodeCrudModel
{
    public $news_root_id;

    /**
     * Returns the static model of the specified AR class.
     * @param string $className active record class name.
     * @return Show the static model class
     */
    public static function model($className = __CLASS__)
    {
        return parent::model($className);
    }

    /**
     * @return string the associated database table name
     */
    public function tableName()
    {
        return 'show';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules()
    {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('news_category_id', 'required'),
            array('news_category_id', 'numerical', 'integerOnly' => true),
            array('video_url', 'length', 'max' => 2048),
            array('date, dateRu', 'safe'),
            // The following rule is used by search().
            // Please remove those attributes that should not be searched.
            array('id, news_category_id, date, video_url', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations()
    {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'newsCategory' => array(self::BELONGS_TO, 'NewsCategory', 'news_category_id'),
            'i18ns' => array(self::HAS_MANY, 'ShowI18n', 'id', 'index' => 'lang'),
            'i18n' => array(self::HAS_ONE, 'ShowI18n', 'id', 'condition' => 'lang=\'' . Yii::app()->language . '\''),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels()
    {
        return array(
            'id' => 'ID',
            'news_category_id' => 'Категория',
            'date' => 'Дата',
            'dateRu' => 'Дата',
            'video_url' => 'Ссылка на видео',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
     */
    public function search()
    {
        // Warning: Please modify the following code to remove attributes that
        // should not be searched.

        $criteria = new CDbCriteria;

//        $criteria->compare('id', $this->id);
        $criteria->compare('news_category_id', $this->news_category_id);
        $criteria->compare('date', $this->date, true);
        $criteria->compare('video_url', $this->video_url, true);

        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
        ));
    }


    public function getDateRu()
    {
        return ($this->date !== null)
            ? date('d.m.Y H:i:s', CDateTimeParser::parse($this->date, 'yyyy-MM-dd hh:mm:ss'))
            : date('d.m.Y H:i:s');
    }

    public function setDateRu($value)
    {
        $this->date = date('Y-m-d H:i:s', CDateTimeParser::parse($value, 'dd.MM.yyyy hh:mm:ss'));
    }

    public function getCategories()
    {
        $criteria = new CDbCriteria();
        $criteria->addCondition('type=4');
        $criteria->compare('news_root_id', $this->news_root_id);

        return CHtml::listData(NewsCategory::model()->with('i18n')->findAll($criteria), 'id', 'i18n.name');
    }

    /**
     * @param Node $node
     * @return void
     */
    public function setNode($node)
    {
        $this->news_root_id = $node->data_id;
    }
}