<?php

/**
 * This is the model class for table "sport_event_category".
 *
 * The followings are the available columns in table 'sport_event_category':
 * @property integer $id
 * @property integer $rank
 * @property integer $calendar_section_id
 *
 * The followings are the available model relations:
 * @property SportEvent[] $sportEvents
 * @property SportEventCategoryI18n[] $i18ns
 * @property SportEventCategoryI18n $i18n
 */
class SportEventCategory extends CActiveRecord    implements INodeCrudModel
{
    /**
     * Returns the static model of the specified AR class.
     * @param string $className active record class name.
     * @return SportEventCategory the static model class
     */
    public static function model($className = __CLASS__)
    {
        return parent::model($className);
    }

    /**
     * @return string the associated database table name
     */
    public function tableName()
    {
        return 'sport_event_category';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules()
    {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('rank', 'numerical', 'integerOnly' => true),
            // The following rule is used by search().
            // Please remove those attributes that should not be searched.
            array('id, rank', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations()
    {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'sportEvents' => array(self::HAS_MANY, 'SportEvent', 'sport_event_category_id'),
            'i18ns' => array(self::HAS_MANY, 'SportEventCategoryI18n', 'id', 'index' => 'lang'),
            'i18n' => array(self::HAS_ONE, 'SportEventCategoryI18n', 'id', 'condition' => 'lang=\'' . Yii::app()->language . '\''),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels()
    {
        return array(
            'id' => 'ID',
            'rank' => 'Rank',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
     */
    public function search()
    {
        // Warning: Please modify the following code to remove attributes that
        // should not be searched.

        $criteria = new CDbCriteria;

//        $criteria->compare('id', $this->id);
        $criteria->compare('rank', $this->rank);
        $criteria->compare('calendar_section_id', $this->calendar_section_id);


        $sort = new CSort();
        $sort->defaultOrder = array(
            'rank' => false,
        );

        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
            'sort' => $sort,
        ));
    }

    /**
     * @param Node $node
     * @return void
     */
    public function setNode($node)
    {
        $this->calendar_section_id = $node->data_id;
    }
}