<?php

/**
 * This is the model class for table "static_data".
 *
 * The followings are the available columns in table 'static_data':
 * @property string $section
 * @property string $key
 * @property string $data
 *
 * The followings are the available model relations:
 * @property StaticDataI18n[] $i18ns
 * @property StaticDataI18n $i18n
 */
class StaticData extends CActiveRecord
{
    /**
     * Returns the static model of the specified AR class.
     * @param string $className active record class name.
     * @return StaticData the static model class
     */
    public static function model($className = __CLASS__)
    {
        return parent::model($className);
    }

    /**
     * @return string the associated database table name
     */
    public function tableName()
    {
        return 'static_data';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules()
    {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('section, key', 'required'),
            array('section, key', 'length', 'max' => 64),
            array('data', 'safe'),
            // The following rule is used by search().
            // Please remove those attributes that should not be searched.
            array('section, key, data', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations()
    {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'i18ns' => array(self::HAS_MANY, 'StaticDataI18n', array('section', 'key'), 'index' => 'lang'),
            'i18n' => array(self::HAS_ONE, 'StaticDataI18n', array('section', 'key'), 'condition' => 'lang=\'' . Yii::app()->language . '\''),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels()
    {
        return array(
            'section' => 'Section',
            'key' => 'Key',
            'data' => 'Data',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
     */
    public function search()
    {
        // Warning: Please modify the following code to remove attributes that
        // should not be searched.

        $criteria = new CDbCriteria;

        $criteria->compare('section', $this->section, true);
        $criteria->compare('key', $this->key, true);
        $criteria->compare('data', $this->data, true);

        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
        ));
    }

    private $_data = null;

    public function getDataAttributes()
    {
        if (!isset($this->_data)) {
            $this->_data = unserialize($this->data);
        }


        return $this->_data;
    }

    public function setDataAttributes($data)
    {
        $this->_data = $data;
        $this->data = serialize($data);
    }
}