<?php

/**
 * This is the model class for table "sto_optional_items".
 *
 * The followings are the available columns in table 'sto_optional_items':
 * @property integer $id
 * @property integer $sto_filter_id
 * @property string $name
 * @property string $period
 * @property string $item_price
 * @property string $service_price
 * @property string $total_price
 */
class StoOptionalItems extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'sto_optional_items';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('sto_filter_id', 'numerical', 'integerOnly'=>true),
			array('name', 'length', 'max'=>255),
			array('period, item_price, service_price, total_price', 'length', 'max'=>45),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('id, sto_filter_id, name, period, item_price, service_price, total_price', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'sto_filter_id' => 'Sto Filter',
			'name' => 'Name',
			'period' => 'Period',
			'item_price' => 'Item Price',
			'service_price' => 'Service Price',
			'total_price' => 'Total Price',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('sto_filter_id',$this->sto_filter_id);
		$criteria->compare('name',$this->name,true);
		$criteria->compare('period',$this->period,true);
		$criteria->compare('item_price',$this->item_price,true);
		$criteria->compare('service_price',$this->service_price,true);
		$criteria->compare('total_price',$this->total_price,true);

		return $this->find($criteria);
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return StoOptionalItems the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
