<?php

/**
 * This is the model class for table "tuning_model".
 *
 * The followings are the available columns in table 'tuning_model':
 * @property integer $id
 * @property integer $tuning_brand_id
 * @property string $link
 * @property string $contacts_data
 * @property string $header_gallery_id
 * @property integer $hidden
 * @property string $code
 *
 * The followings are the available model relations:
 * @property TuningBrand $tuningBrand
 * @property TuningModelI18n[] $i18ns
 * @property TuningModelI18n $i18n
 * @property TuningSet[] $tuningSets
 *
 * @property ImageARBehavior $imageBehavior
 * @property GalleryBehavior  $headerGalleryBehavior
 */
class TuningModel extends CActiveRecord implements INodeCrudModel
{

    public $tuning_root_id;

    /**
     * Returns the static model of the specified AR class.
     * @param string $className active record class name.
     * @return TuningModel the static model class
     */
    public static function model($className = __CLASS__)
    {
        return parent::model($className);
    }

    /**
     * @return string the associated database table name
     */
    public function tableName()
    {
        return 'tuning_model';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules()
    {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('tuning_brand_id', 'required'),
            array('tuning_brand_id', 'numerical', 'integerOnly' => true),
            array('link', 'length', 'max' => 64),
            array('link', 'unique',),
            array('contactIds', 'safe'),
            // The following rule is used by search().
            // Please remove those attributes that should not be searched.
            array('id, tuning_brand_id, link, contacts_data', 'safe', 'on' => 'search'),
            array('hidden, code', 'safe'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations()
    {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'tuningBrand' => array(self::BELONGS_TO, 'TuningBrand', 'tuning_brand_id'),
            'i18ns' => array(self::HAS_MANY, 'TuningModelI18n', 'id', 'index' => 'lang'),
            'i18n' => array(self::HAS_ONE, 'TuningModelI18n', 'id', 'condition' => 'lang=\'' . Yii::app()->language . '\''),
            'tuningSets' => array(self::HAS_MANY, 'TuningSet', 'tuning_model_id'),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels()
    {
        return array(
            'id' => 'ID',
            'tuning_brand_id' => 'Марка авто',
            'link' => 'Псевдоним в адресной строке',
            'contactIds' => 'Контакты для отображения в сайдбаре',
            'image' => 'Фото модели авто',
            'hidden' => 'Страница скрыта',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
     */
    public function search()
    {
        // Warning: Please modify the following code to remove attributes that
        // should not be searched.

        $criteria = new CDbCriteria;

//        $criteria->compare('id', $this->id);


        if (isset($this->tuning_brand_id))
            $criteria->compare('tuning_brand_id', $this->tuning_brand_id);
        else
            $criteria->addInCondition('tuning_brand_id', array_keys($this->getTuningBrands()));
        $criteria->compare('link', $this->link, true);
        $criteria->compare('contacts_data', $this->contacts_data, true);

        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
        ));
    }

    public function getContactIds()
    {
        return explode(',', $this->contacts_data);
    }

    public function setContactIds($value)
    {
        if (is_array($value))
            $this->contacts_data = implode(',', $value);
        else
            $this->contacts_data = $value;
    }


    public $image;

    public function behaviors()
    {
        return array(
            'imageBehavior' => array(
                'class' => 'ImageARBehavior',
                'attribute' => 'image', // this must exist
                'extension' => 'png, gif, jpg, jpeg', // possible extensions, comma separated
                'prefix' => 'img_',
                'relativeWebRootFolder' => 'images/tuningModels', // this folder must exist

                //'forceExt' => 'png',
                'formats' => array(
                    'small' => array(
                        'suffix' => '_small',
                        'process' => array(
                            'centeredpreview' => array(134, 96),
//                            'crop' => array(133, 57, 'center'),
                        ),
                    ),
                    'medium' => array(
                        'suffix' => '_medium',
                        'process' => array(
                            'centeredpreview' => array(280, 210),
//                            'crop' => array(133, 57, 'center'),
                        ),
                    ),
                    'normal' => array(),
                ),

                'defaultName' => 'default',
            ),
            'headerGalleryBehavior' => array(
                'class' => 'GalleryBehavior',
                'idAttribute' => 'header_gallery_id',
                'versions' => array(
                    'gallery' => array(
                        'centeredpreview' => array(1008, 115),
                    )
                ),
                'name' => true,
                'description' => true,
            ),
        );
    }


    public function save($runValidation = true, $attributes = null)
    {
        $r = parent::save($runValidation, $attributes);
        if (empty($this->link)) {
            $this->link = $this->id;
            $this->saveAttributes($this->attributes);
        }
        return $r;
    }

    /**
     * @param Node $node
     * @return void
     */
    public function setNode($node)
    {
        $this->tuning_root_id = $node->data_id;
    }

    public function getTuningBrands()
    {
        $criteria = new CDbCriteria();
        $criteria->compare('tuning_root_id', $this->tuning_root_id);

        return CHtml::listData(TuningBrand::model()->findAll($criteria), 'id', 'i18n.name');
    }
}