<?php

/**
 * This is the model class for table "tuning_root".
 *
 * The followings are the available columns in table 'tuning_root':
 * @property integer $id
 * @property string $contacts_data
 * @property integer $header_gallery_id
 * @property string $feedback_email
 *
 * The followings are the available model relations:
 * @property TuningBrand[] $tuningBrands
 * @property TuningRootI18n[] $i18ns
 * @property TuningRootI18n $i18n
 * @property TuningService[] $tuningServices
 */
class TuningRoot extends CActiveRecord
{
    /**
     * Returns the static model of the specified AR class.
     * @param string $className active record class name.
     * @return TuningRoot the static model class
     */
    public static function model($className = __CLASS__)
    {
        return parent::model($className);
    }

    /**
     * @return string the associated database table name
     */
    public function tableName()
    {
        return 'tuning_root';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules()
    {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('header_gallery_id', 'numerical', 'integerOnly' => true),
            array('feedback_email', 'length', 'max' => 512),
            array('contacts_data, contactIds', 'safe'),
            // The following rule is used by search().
            // Please remove those attributes that should not be searched.
            array('id, contacts_data, header_gallery_id, feedback_email', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations()
    {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'tuningBrands' => array(self::HAS_MANY, 'TuningBrand', 'tuning_root_id'),
            'i18ns' => array(self::HAS_MANY, 'TuningRootI18n', 'id', 'index' => 'lang'),
            'i18n' => array(self::HAS_ONE, 'TuningRootI18n', 'id', 'condition' => 'lang=\'' . Yii::app()->language . '\''),
            'tuningServices' => array(self::HAS_MANY, 'TuningService', 'tuning_root_id'),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels()
    {
        return array(
            'id' => 'ID',
            'contacts_data' => 'Контакты в сайдбаре',
            'header_gallery_id' => 'Галереея в шапке',
            'contactIds' => 'Контакты для отображения в сайдбаре',
            'feedback_email' => 'Адресс для писем с формы обратной связи',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
     */
    public function search()
    {
        // Warning: Please modify the following code to remove attributes that
        // should not be searched.

        $criteria = new CDbCriteria;

//        $criteria->compare('id', $this->id);
        $criteria->compare('contacts_data', $this->contacts_data, true);
        $criteria->compare('header_gallery_id', $this->header_gallery_id);
        $criteria->compare('feedback_email', $this->feedback_email, true);

        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
        ));
    }

    public function getContactIds()
    {
        return explode(',', $this->contacts_data);
    }

    public function setContactIds($value)
    {
        if (is_array($value))
            $this->contacts_data = implode(',', $value);
        else
            $this->contacts_data = $value;
    }


    public function behaviors()
    {
        return array(
            'galleryBehavior' => array(
                'class' => 'GalleryBehavior',
                'idAttribute' => 'header_gallery_id',
                'versions' => array(
                    'gallery' => array(
                        'centeredpreview' => array(1008, 115),
                    )
                ),
                'name' => true,
                'description' => true,
            ),
        );
    }
}