<?php

/**
 * This is the model class for table "tuning_set".
 *
 * The followings are the available columns in table 'tuning_set':
 * @property integer $id
 * @property integer $tuning_model_id
 * @property integer $gallery_id
 * @property string $link
 * @property string $contacts_data
 * @property integer $hidden
 * @property string $code
 * @property integer $rank
 *
 * The followings are the available model relations:
 * @property TuningModel $tuningModel
 * @property TuningSetI18n[] $i18ns
 * @property TuningSetI18n $i18n
 *
 * @property ImageARBehavior $imageBehavior
 * @property GalleryBehavior  $galleryBehavior
 */
class TuningSet extends CActiveRecord implements INodeCrudModel
{
    public $tuning_root_id;

    /**
     * Returns the static model of the specified AR class.
     * @param string $className active record class name.
     * @return TuningSet the static model class
     */
    public static function model($className = __CLASS__)
    {
        return parent::model($className);
    }

    /**
     * @return string the associated database table name
     */
    public function tableName()
    {
        return 'tuning_set';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules()
    {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('tuning_model_id', 'required'),
            array('tuning_model_id, gallery_id', 'numerical', 'integerOnly' => true),
            array('link', 'length', 'max' => 64),
            array('link', 'unique',),
            array('contactIds, rank', 'safe'),
            // The following rule is used by search().
            // Please remove those attributes that should not be searched.
            array('id, tuning_model_id, gallery_id, link, contacts_data', 'safe', 'on' => 'search'),
            array('hidden, code', 'safe'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations()
    {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'tuningModel' => array(self::BELONGS_TO, 'TuningModel', 'tuning_model_id'),
            'i18ns' => array(self::HAS_MANY, 'TuningSetI18n', 'id', 'index' => 'lang'),
            'i18n' => array(self::HAS_ONE, 'TuningSetI18n', 'id', 'condition' => 'lang=\'' . Yii::app()->language . '\''),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels()
    {
        return array(
            'id' => 'ID',
            'tuning_model_id' => 'Модель авто',
            'gallery_id' => 'Gallery',
            'link' => 'Псевдоним в адресной строке',
            'contactIds' => 'Контакты для отображения в сайдбаре',
            'image' => 'Фото',
            'hidden' => 'Страница скрыта',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
     */
    public function search()
    {
        // Warning: Please modify the following code to remove attributes that
        // should not be searched.

        $criteria = new CDbCriteria;

//        $criteria->compare('id', $this->id);

        if (isset($this->tuning_model_id))
            $criteria->compare('tuning_model_id', $this->tuning_model_id);
        else
            $criteria->addInCondition('tuning_model_id', array_keys($this->getTuningModels()));

        $criteria->compare('gallery_id', $this->gallery_id);
        $criteria->compare('link', $this->link, true);
        $criteria->compare('contacts_data', $this->contacts_data, true);

        $sort = new CSort();
        $sort->defaultOrder = array(
            'rank' => false,
        );

        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
            'sort' => $sort,
        ));
    }

    public function getContactIds()
    {
        return explode(',', $this->contacts_data);
    }

    public function setContactIds($value)
    {
        if (is_array($value))
            $this->contacts_data = implode(',', $value);
        else
            $this->contacts_data = $value;
    }


    public $image;

    public function behaviors()
    {
        return array(
            'imageBehavior' => array(
                'class' => 'ImageARBehavior',
                'attribute' => 'image', // this must exist
                'extension' => 'png, gif, jpg, jpeg', // possible extensions, comma separated
                'prefix' => 'img_',
                'relativeWebRootFolder' => 'images/tuningSets', // this folder must exist

                'forceExt' => 'png',
                'formats' => array(
                    'medium' => array(
                        'suffix' => '_medium',
                        'process' => array(
                            'centeredpreview' => array(304, 227),
//                            'crop' => array(133, 57, 'center'),
                        ),
                    ),
                    'big' => array(
                        'suffix' => '_big',
                        'process' => array(
                            'centeredpreview' => array(632, 473),
//                            'crop' => array(133, 57, 'center'),
                        ),
                    ),
                    'bigger' => array(
                        'suffix' => '_bigger',
                        'process' => array(
                            'resize' => array(800, null),
//                            'crop' => array(133, 57, 'center'),
                        ),
                    ),
                    'normal' => array(),
                ),

                'defaultName' => 'default',
            ),
            'galleryBehavior' => array(
                'class' => 'GalleryBehavior',
                'idAttribute' => 'gallery_id',
                'versions' => array(
                    'small' => array(
                        'centeredpreview' => array(140, 105),
                    ),
                    'medium' => array(
                        'cresize' => array(800, null),
                        'watermark' => array('images/watermark.png', 0, 0),
                    )
                ),
                'name' => true,
                'description' => true,
            ),
        );
    }

    public function save($runValidation = true, $attributes = null)
    {
        $r = parent::save($runValidation, $attributes);
        if (empty($this->link)) {
            $this->link = $this->id;
            $this->saveAttributes($this->attributes);
        }
        return $r;
    }

    /**
     * @param Node $node
     * @return void
     */
    public function setNode($node)
    {
        $this->tuning_root_id = $node->data_id;
    }


    public function getTuningModels()
    {
        $criteria = new CDbCriteria();
        $criteria->with = array('tuningBrand');
        $criteria->compare('tuningBrand.tuning_root_id', $this->tuning_root_id);

        return CHtml::listData(TuningModel::model()->findAll($criteria), 'id', 'i18n.name');
    }
}