<?php

/**
 * This is the model class for table "work".
 *
 * The followings are the available columns in table 'work':
 * @property integer $id
 * @property integer $work_model_id
 * @property integer $gallery_id
 * @property string $link
 * @property string $contacts_data
 * @property string $date
 * @property integer $hidden
 * @property string $code
 *
 * The followings are the available model relations:
 * @property WorkModel $workModel
 * @property WorkI18n[] $i18ns
 * @property WorkI18n $i18n
 *
 * @property ImageARBehavior $imageBehavior
 * @property ImageARBehavior $ownerImageBehavior
 * @property GalleryBehavior  $galleryBehavior
 */
class Work extends CActiveRecord implements INodeCrudModel
{
    /**
     * Returns the static model of the specified AR class.
     * @param string $className active record class name.
     * @return Work the static model class
     */
    public static function model($className = __CLASS__)
    {
        return parent::model($className);
    }

    /**
     * @return string the associated database table name
     */
    public function tableName()
    {
        return 'work';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules()
    {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('work_model_id', 'required'),
            array('work_model_id, gallery_id', 'numerical', 'integerOnly' => true),
            array('link', 'length', 'max' => 64),
            array('link', 'unique',),
            array('contactIds, date, dateRu', 'safe'),
            // The following rule is used by search().
            // Please remove those attributes that should not be searched.
            array('id, work_model_id, gallery_id, link, contacts_data', 'safe', 'on' => 'search'),
            array('hidden, code', 'safe'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations()
    {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'workModel' => array(self::BELONGS_TO, 'WorkModel', 'work_model_id'),
            'i18ns' => array(self::HAS_MANY, 'WorkI18n', 'id', 'index' => 'lang'),
            'i18n' => array(self::HAS_ONE, 'WorkI18n', 'id', 'condition' => 'lang=\'' . Yii::app()->language . '\''),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels()
    {
        return array(
            'id' => 'ID',
            'work_model_id' => 'Модель авто',
            'gallery_id' => 'Gallery',
            'link' => 'Псевдоним в адресной строке',
            'contactIds' => 'Контакты для отображения в сайдбаре',
            'image' => 'Фото',
            'owner_image' => 'Фото владельца',
            'date'=>'Дата создания машины',
            'dateRu'=>'Дата создания машины',
            'hidden' => 'Страница скрыта',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
     */
    public function search()
    {
        // Warning: Please modify the following code to remove attributes that
        // should not be searched.

        $criteria = new CDbCriteria;

//        $criteria->compare('id', $this->id);

        if (isset($this->work_model_id))
            $criteria->compare('work_model_id', $this->work_model_id);
        else
            $criteria->addInCondition('work_model_id', array_keys($this->getWorkModels()));


        $criteria->compare('gallery_id', $this->gallery_id);
        $criteria->compare('link', $this->link, true);
        $criteria->compare('contacts_data', $this->contacts_data, true);

        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
        ));
    }

    public function getContactIds()
    {
        return explode(',', $this->contacts_data);
    }

    public function setContactIds($value)
    {
        if (is_array($value))
            $this->contacts_data = implode(',', $value);
        else
            $this->contacts_data = $value;
    }


    public $image;
    public $owner_image;
    public $work_root_id;

    public function behaviors()
    {
        return array(
            'imageBehavior' => array(
                'class' => 'ImageARBehavior',
                'attribute' => 'image', // this must exist
                'extension' => 'png, gif, jpg, jpeg', // possible extensions, comma separated
                'prefix' => 'img_',
                'relativeWebRootFolder' => 'images/works', // this folder must exist

                'forceExt' => 'png',
                'formats' => array(
                    'medium' => array(
                        'suffix' => '_medium',
                        'process' => array(
                            'centeredpreview' => array(384, 285),
//                            'crop' => array(133, 57, 'center'),
                        ),
                    ),
//                    'big' => array(
//                        'suffix' => '_big',
//                        'process' => array(
//                            'centeredpreview' => array(632, 473),
//                            //'crop' => array(133, 57, 'center'),
//                        ),
//                    ),
                    'normal' => array(),
                ),

                'defaultName' => 'default',
            ),
            'ownerImageBehavior' => array(
                'class' => 'ImageARBehavior',
                'attribute' => 'owner_image', // this must exist
                'extension' => 'png, gif, jpg, jpeg', // possible extensions, comma separated
                'prefix' => 'owner_',
                'relativeWebRootFolder' => 'images/works', // this folder must exist

                'formats' => array(
                    'medium' => array(
                        'suffix' => '_medium',
                        'process' => array(
                            'resize' => array(140, null),
                        ),
                    ),
                    'normal' => array(),
                ),

                'defaultName' => 'default',
            ),
            'galleryBehavior' => array(
                'class' => 'GalleryBehavior',
                'idAttribute' => 'gallery_id',
                'versions' => array(
                    'small' => array(
                        'centeredpreview' => array(140, 105),
                    ),
                    'medium' => array(
                        'cresize' => array(800, null),
                        'watermark'=>array('images/watermark.png',0,0)  ,
                    )
                ),
                'name' => true,
                'description' => true,
            ),
        );
    }

    public function save($runValidation = true, $attributes = null)
    {
        $r = parent::save($runValidation, $attributes);
        if (empty($this->link)) {
            $this->link = $this->id;
            $this->saveAttributes($this->attributes);
        }
        return $r;
    }


    public function getDateRu()
    {
        return ($this->date !== null)
            ? date('d.m.Y', CDateTimeParser::parse($this->date, 'yyyy-MM-dd'))
            : date('d.m.Y');
    }

    public function setDateRu($value)
    {
        $this->date = date('Y-m-d', CDateTimeParser::parse($value, 'dd.MM.yyyy'));
    }



    /**
     * @param Node $node
     * @return void
     */
    public function setNode($node)
    {
        $this->work_root_id = $node->data_id;
    }


    public function getWorkModels()
    {
        $criteria = new CDbCriteria();
        $criteria->with = array('workBrand');
        $criteria->compare('workBrand.work_root_id', $this->work_root_id);

        return CHtml::listData(WorkModel::model()->findAll($criteria), 'id', 'i18n.name');
    }
}