<?php

/**
 * This is the model class for table "work_i18n".
 *
 * The followings are the available columns in table 'work_i18n':
 * @property integer $id
 * @property string $lang
 * @property string $name
 * @property string $page_name
 * @property string $short
 * @property string $content
 * @property string $title
 * @property string $keywords
 * @property string $description
 * @property string $owner_name
 * @property string $owner_age
 * @property string $owner_status
 * @property string $owner_favorite_author
 * @property string $owner_hobby
 * @property string $owner_expectations
 *
 * The followings are the available model relations:
 * @property Work $work
 */
class WorkI18n extends CActiveRecord
{
    /**
     * Returns the static model of the specified AR class.
     * @param string $className active record class name.
     * @return WorkI18n the static model class
     */
    public static function model($className = __CLASS__)
    {
        return parent::model($className);
    }

    /**
     * @return string the associated database table name
     */
    public function tableName()
    {
        return 'work_i18n';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules()
    {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('name, page_name, title', 'length', 'max' => 512),
            array('owner_name, owner_age, owner_status, owner_favorite_author, owner_hobby', 'length', 'max' => 64),
            array('short, content, keywords, description, owner_expectations', 'safe'),
            // The following rule is used by search().
            // Please remove those attributes that should not be searched.
            array('id, lang, name, page_name, short, content, title, keywords, description, owner_name, owner_age, owner_status, owner_favorite_author, owner_hobby, owner_expectations', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations()
    {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'work' => array(self::BELONGS_TO, 'Work', 'id'),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels()
    {
        return array(
            'id' => 'ID',
            'lang' => 'Lang',
            'name' => 'Название',
            'page_name' => 'Название страницы',
            'content' => 'Содержимое',
            'short' => 'Кратко о работе',
            'title' => 'Заголовок',
            'keywords' => 'Ключевые слова',
            'description' => 'Описание страницы',
            'owner_name' => 'Имя',
            'owner_age' => 'Возраст',
            'owner_status' => 'Личный статус',
            'owner_favorite_author' => 'Любимый автор',
            'owner_hobby' => 'Хобби',
            'owner_expectations' => 'Ожидания',
            'owner_comment' => 'Отзыв',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
     */
    public function search()
    {
        // Warning: Please modify the following code to remove attributes that
        // should not be searched.

        $criteria = new CDbCriteria;

//        $criteria->compare('id', $this->id);
        $criteria->compare('lang', $this->lang, true);
        $criteria->compare('name', $this->name, true);
        $criteria->compare('page_name', $this->page_name, true);
        $criteria->compare('short', $this->short, true);
        $criteria->compare('content', $this->content, true);
        $criteria->compare('title', $this->title, true);
        $criteria->compare('keywords', $this->keywords, true);
        $criteria->compare('description', $this->description, true);
        $criteria->compare('owner_name', $this->owner_name, true);
        $criteria->compare('owner_age', $this->owner_age, true);
        $criteria->compare('owner_status', $this->owner_status, true);
        $criteria->compare('owner_favorite_author', $this->owner_favorite_author, true);
        $criteria->compare('owner_hobby', $this->owner_hobby, true);
        $criteria->compare('owner_expectations', $this->owner_expectations, true);

        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
        ));
    }
}